"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var CodeMirror = require("codemirror");
/**
 * CodeMirror component
 * Usage :
 * <codemirror [(ngModel)]="data" [config]="{...}"></codemirror>
 */
var CodemirrorComponent = (function () {
    /**
     * Constructor
     */
    function CodemirrorComponent() {
        this.change = new core_1.EventEmitter();
        this.focus = new core_1.EventEmitter();
        this.blur = new core_1.EventEmitter();
        this.cursorActivity = new core_1.EventEmitter();
        this.instance = null;
        this._value = '';
    }
    Object.defineProperty(CodemirrorComponent.prototype, "value", {
        get: function () { return this._value; },
        set: function (v) {
            if (v !== this._value) {
                this._value = v;
                this.onChange(v);
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * On component destroy
     */
    /**
       * On component destroy
       */
    CodemirrorComponent.prototype.ngOnDestroy = /**
       * On component destroy
       */
    function () {
    };
    /**
     * On component view init
     */
    /**
       * On component view init
       */
    CodemirrorComponent.prototype.ngAfterViewInit = /**
       * On component view init
       */
    function () {
        this.config = this.config || {};
        this.codemirrorInit(this.config, this.size);
    };
    /**
     * Initialize codemirror
     */
    /**
       * Initialize codemirror
       */
    CodemirrorComponent.prototype.codemirrorInit = /**
       * Initialize codemirror
       */
    function (config, size) {
        var _this = this;
        this.instance = CodeMirror.fromTextArea(this.host.nativeElement, config);
        this.instance.setValue(this._value);
        this.instance.on('change', function () {
            _this.updateValue(_this.instance.getValue());
        });
        this.instance.on('focus', function (instance, event) {
            _this.focus.emit({ instance: instance, event: event });
        });
        this.instance.on('cursorActivity', function (instance) {
            _this.cursorActivity.emit({ instance: instance });
        });
        this.instance.on('blur', function (instance, event) {
            _this.blur.emit({ instance: instance, event: event });
        });
        if (this.size != undefined) {
            this.instance.setSize(this.size.w, this.size.h);
        }
    };
    /**
     * Value update process
     */
    /**
       * Value update process
       */
    CodemirrorComponent.prototype.updateValue = /**
       * Value update process
       */
    function (value) {
        this.value = value;
        this.onTouched();
        this.change.emit(value);
    };
    /**
     * Implements ControlValueAccessor
     */
    /**
       * Implements ControlValueAccessor
       */
    CodemirrorComponent.prototype.writeValue = /**
       * Implements ControlValueAccessor
       */
    function (value) {
        this._value = value || '';
        if (this.instance) {
            this.instance.setValue(this._value);
        }
    };
    CodemirrorComponent.prototype.onChange = function (_) { };
    CodemirrorComponent.prototype.onTouched = function () { };
    CodemirrorComponent.prototype.registerOnChange = function (fn) { this.onChange = fn; };
    CodemirrorComponent.prototype.registerOnTouched = function (fn) { this.onTouched = fn; };
    CodemirrorComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'codemirror',
                    providers: [
                        {
                            provide: forms_1.NG_VALUE_ACCESSOR,
                            useExisting: core_1.forwardRef(function () { return CodemirrorComponent; }),
                            multi: true
                        }
                    ],
                    template: "<textarea #host></textarea>",
                },] },
    ];
    /** @nocollapse */
    CodemirrorComponent.ctorParameters = function () { return []; };
    CodemirrorComponent.propDecorators = {
        "config": [{ type: core_1.Input },],
        "size": [{ type: core_1.Input },],
        "change": [{ type: core_1.Output },],
        "focus": [{ type: core_1.Output },],
        "blur": [{ type: core_1.Output },],
        "cursorActivity": [{ type: core_1.Output },],
        "host": [{ type: core_1.ViewChild, args: ['host',] },],
        "instance": [{ type: core_1.Output },],
        "value": [{ type: core_1.Input },],
    };
    return CodemirrorComponent;
}());
exports.CodemirrorComponent = CodemirrorComponent;
//# sourceMappingURL=codemirror.component.js.map